% dsge_loaddata.m
% load data for estimation
clear temp_YYR temp_YYP temp_inflexpt

cd(datapath);

% Load estimation sample
temp_YYR = load(datasetstr);
tiR      = temp_YYR(:,1);

% Load prdiction sample
temp_YYP = load(predsetstr);
tiP      = temp_YYP(:,1);

cd(workpath);

% Some information
Tend    = size(temp_YYR,1);
hmaxact = size(temp_YYP,1);

% -------------------------------------------------------------------------
% data transformation
% -------------------------------------------------------------------------
%   - Multiply 4 by inflation
%   - Multiply 4 by fed fund rates
%   - Expectation inflation rate is in % (yearly) -> don't need to multiply
%                                                    by 4
%  <Remark>
%    Original data (from vintages) is constructed 
%   in a way that inflation and interest rate are 
%   in quarterly growth (in %). (Minchul)
% -------------------------------------------------------------------------
% note that in the original data
% YYR: growth is in per-capita, YYR(:,12) is pop growth
% YYP: growth is NOT in per-capita, YYP(:,10) is pop growth
if estinfo.percapita == 1
    % YYR = [temp_YYR(:,2), 4*temp_YYR(:,5), 4*temp_YYR(:,6), R_inflexpt(:,2)];
    % YYP = [temp_YYP(:,2), 4*temp_YYP(:,5), 4*temp_YYP(:,6), P_inflexpt(:,2)];
    YYR   = [temp_YYR(:,2), 4*temp_YYR(:,5), 4*temp_YYR(:,6)];
    % YYP = [temp_YYP(:,2), 4*temp_YYP(:,5), 4*temp_YYP(:,6)];
    YYP   = [temp_YYP(:,2)-temp_YYP(:,10), 4*temp_YYP(:,5), 4*temp_YYP(:,6)]; %per-capita
    YYPOP = temp_YYP(:,10);
elseif estinfo.percapita == 0
    YYR   = [temp_YYR(:,2)+temp_YYR(:,12), 4*temp_YYR(:,5), 4*temp_YYR(:,6)];
    YYP   = [temp_YYP(:,2), 4*temp_YYP(:,5), 4*temp_YYP(:,6)]; %per-capita
    YYPOP = temp_YYP(:,10);
end
% -------------------------------------------------------------------------
% Load expectation data if needed
% -------------------------------------------------------------------------
% raw: BC+SPF infl-10y
% c1: BC+SPF corrected by DS's method (substract 0.5 to account for CPI-GDP
% deflator difference)
% c2: Same as c1 except that BC 10y is for GNP deflator prior to 1983 (see the SPF manual)
% -------------------------------------------------------------------------

if estinfo.infle == 1
    cd(datapath);
    
    inflsetstr = 'infl_ex10y_c2.txt';
    
    % load
    temp_inflexpt = load(inflsetstr);
    
    % retrieve info
    tiE      = temp_inflexpt(:,1);
    R_inflexpt = temp_inflexpt(1:Tend,:);
    P_inflexpt = temp_inflexpt(Tend+1:Tend+hmaxact,:);
    
    % patch data
    YYR = [YYR, R_inflexpt(:,2)];
    YYP = [YYP, P_inflexpt(:,2)];
    cd(workpath);
end





